==> qastools_1.1.0.orig.tar.xz: qastools-v1.1.0/shared/src/wdg/layout_weights.hpp <==
/// QasTools: Desktop toolset for the Linux sound system ALSA.
/// \copyright See COPYING file.

#pragma once

#include <cstddef>

namespace Wdg
{

/// @brief Layout_Weights
///
class Layout_Weights
{
  // Public methods
  public:
  // -- Construction

  Layout_Weights () = default;

  Layout_Weights ( unsigned int * values_n )
  {
    for ( ::std::size_t ii = 0; ii < 4; ++ii ) {
      _weights[ ii ] = values_n[ ii ];
    }
  }

  Layout_Weights ( unsigned long * values_n )
  {
    for ( ::std::size_t ii = 0; ii < 4; ++ii ) {
      _weights[ ii ] = values_n[ ii ];
    }
  }

  Layout_Weights ( unsigned long value_all_n )
  {
    for ( ::std::size_t ii = 0; ii < 4; ++ii ) {
      _weights[ ii ] = value_all_n;
    }
  }

  ~Layout_Weights () = default;
  ;

  unsigned long
  sum () const
  {
    unsigned long res = 0;
    for ( ::std::size_t ii = 0; ii < 4; ++ii ) {
      res += _weights[ ii ];
    }
    return res;
  }

  void
  set_all ( unsigned long value_n )
  {
    for ( ::std::size_t ii = 0; ii < 4; ++ii ) {
      _weights[ ii ] = value_n;
    }
  }

  void
  normalize ( unsigned long weight_normal_n = 4096 );

  unsigned long
  operator[] ( ::std::size_t idx_n ) const
  {
    return _weights[ idx_n ];
  }

  unsigned long &
  operator[] ( ::std::size_t idx_n )
  {
    return _weights[ idx_n ];
  }

  // Private attributes
  private:
  unsigned long _weights[ 4 ] = { 0, 0, 0, 0 };
};

unsigned int
calc_weights_delta_order ( unsigned int * order_n,
                           const Layout_Weights & wnorm_req_n,
                           const Layout_Weights & wnorm_cur_n );
} // namespace Wdg

==> qastools_1.2.0.orig.tar.xz: qastools-v1.2.0/shared/src/wdg/layout_weights.hpp <==
/// QasTools: Desktop toolset for the Linux sound system ALSA.
/// \copyright See COPYING file.

#pragma once

#include <cstddef>

namespace Wdg
{

/// @brief Layout_Weights
///
class Layout_Weights
{
  public:
  // -- Construction

  Layout_Weights () = default;

  Layout_Weights ( unsigned int * values_n )
  {
    for ( std::size_t ii = 0; ii < 4; ++ii ) {
      _weights[ ii ] = values_n[ ii ];
    }
  }

  Layout_Weights ( unsigned long * values_n )
  {
    for ( std::size_t ii = 0; ii < 4; ++ii ) {
      _weights[ ii ] = values_n[ ii ];
    }
  }

  Layout_Weights ( unsigned long value_all_n )
  {
    for ( std::size_t ii = 0; ii < 4; ++ii ) {
      _weights[ ii ] = value_all_n;
    }
  }

  ~Layout_Weights () = default;
  ;

  unsigned long
  sum () const
  {
    unsigned long res = 0;
    for ( std::size_t ii = 0; ii < 4; ++ii ) {
      res += _weights[ ii ];
    }
    return res;
  }

  void
  set_all ( unsigned long value_n )
  {
    for ( std::size_t ii = 0; ii < 4; ++ii ) {
      _weights[ ii ] = value_n;
    }
  }

  void
  normalize ( unsigned long weight_normal_n = 4096 );

  unsigned long
  operator[] ( std::size_t idx_n ) const
  {
    return _weights[ idx_n ];
  }

  unsigned long &
  operator[] ( std::size_t idx_n )
  {
    return _weights[ idx_n ];
  }

  private:
  // -- Attributes
  unsigned long _weights[ 4 ] = { 0, 0, 0, 0 };
};

unsigned int
calc_weights_delta_order ( unsigned int * order_n,
                           const Layout_Weights & wnorm_req_n,
                           const Layout_Weights & wnorm_cur_n );
} // namespace Wdg
